@@ -3,6 +3,7 @@ from typing import Any, Dict, Optional
 import httpx
 
 from ...client import Client
+from ...models.create_workspace_request import CreateWorkspaceRequest
 from ...models.workspace import Workspace
 from ...types import Response
 
@@ -10,18 +11,22 @@ from ...types import Response
 def _get_kwargs(
     *,
     client: Client,
+    json_body: CreateWorkspaceRequest,
 ) -> Dict[str, Any]:
     url = "{}/workspaces".format(client.base_url)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
+    json_json_body = json_body.to_dict()
+
     return {
         "method": "post",
         "url": url,
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
+        "json": json_json_body,
     }
 
 
@@ -45,15 +50,20 @@ def _build_response(*, response: httpx.Response) -> Response[Workspace]:
 def sync_detailed(
     *,
     client: Client,
+    json_body: CreateWorkspaceRequest,
 ) -> Response[Workspace]:
     """Create a workspace
 
+    Args:
+        json_body (CreateWorkspaceRequest):
+
     Returns:
         Response[Workspace]
     """
 
     kwargs = _get_kwargs(
         client=client,
+        json_body=json_body,
     )
 
     response = httpx.request(
@@ -67,30 +77,40 @@ def sync_detailed(
 def sync(
     *,
     client: Client,
+    json_body: CreateWorkspaceRequest,
 ) -> Optional[Workspace]:
     """Create a workspace
 
+    Args:
+        json_body (CreateWorkspaceRequest):
+
     Returns:
         Response[Workspace]
     """
 
     return sync_detailed(
         client=client,
+        json_body=json_body,
     ).parsed
 
 
 async def asyncio_detailed(
     *,
     client: Client,
+    json_body: CreateWorkspaceRequest,
 ) -> Response[Workspace]:
     """Create a workspace
 
+    Args:
+        json_body (CreateWorkspaceRequest):
+
     Returns:
         Response[Workspace]
     """
 
     kwargs = _get_kwargs(
         client=client,
+        json_body=json_body,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
@@ -102,9 +122,13 @@ async def asyncio_detailed(
 async def asyncio(
     *,
     client: Client,
+    json_body: CreateWorkspaceRequest,
 ) -> Optional[Workspace]:
     """Create a workspace
 
+    Args:
+        json_body (CreateWorkspaceRequest):
+
     Returns:
         Response[Workspace]
     """
@@ -112,5 +136,6 @@ async def asyncio(
     return (
         await asyncio_detailed(
             client=client,
+            json_body=json_body,
         )
     ).parsed
